@@ -54,7 +54,7 @@ tigris_cache_dir <- function(path) {
 #' @param keep_zipped_shapefile If set to TRUE, do not delete zipped shapefile
 #' (stored in temporary directory or TIGRIS_CACHE_DIR depending on the configuration of
 #' global option "tigris_use_cache"). Defaults to FALSE.
-#' @param query # Defunct. Has no effect.
+#' @param filter_by Geometry used to filter the output returned by the function.  Can be an sf object, an object of class `bbox`, or a length-4 vector of format `c(xmin, ymin, xmax, ymax)` that can be converted to a bbox. Geometries that intersect the input to `filter_by` will be returned.
 #'
 #' @return sf or sp data frame
 #'
@@ -64,9 +64,13 @@ load_tiger <- function(url,
                        class = getOption("tigris_class", "sf"),
                        progress_bar = TRUE,
                        keep_zipped_shapefile = FALSE,
-                       query = NULL) {
+                       filter_by = NULL) {
 
   use_cache <- getOption("tigris_use_cache", FALSE)
+
+  # Process filter_by
+  wkt_filter <- input_to_wkt(filter_by)
+
   tiger_file <- basename(url)
 
   obj <- NULL
@@ -168,27 +172,13 @@ load_tiger <- function(url,
 
       }
 
-      if (class == "sp") {
+      obj <- st_read(dsn = cache_dir, layer = shape,
+                     quiet = TRUE, stringsAsFactors = FALSE,
+                     wkt_filter = wkt_filter)
 
-        obj <- readOGR(dsn = cache_dir, layer = shape, encoding = "UTF-8",
-                       verbose = FALSE, stringsAsFactors = FALSE)
+      if (is.na(st_crs(obj)$proj4string)) {
 
-        if (is.na(proj4string(obj))) {
-
-          proj4string(obj) <- CRS("+proj=longlat +datum=NAD83 +no_defs")
-
-        }
-
-      } else if (class == "sf") {
-
-        obj <- st_read(dsn = cache_dir, layer = shape,
-                       quiet = TRUE, stringsAsFactors = FALSE)
-
-        if (is.na(st_crs(obj)$proj4string)) {
-
-          st_crs(obj) <- "+proj=longlat +datum=NAD83 +no_defs"
-
-        }
+        st_crs(obj) <- "+proj=longlat +datum=NAD83 +no_defs"
 
       }
 
@@ -211,28 +201,13 @@ load_tiger <- function(url,
     shape <- gsub(".zip", "", tiger_file)
     shape <- gsub("_shp", "", shape) # for historic tracts
 
+    obj <- st_read(dsn = tmp, layer = shape,
+                   quiet = TRUE, stringsAsFactors = FALSE,
+                   wkt_filter = wkt_filter)
 
-    if (class == "sp") {
+    if (is.na(st_crs(obj)$proj4string)) {
 
-      obj <- readOGR(dsn = tmp, layer = shape, encoding = "UTF-8",
-                     verbose = FALSE, stringsAsFactors = FALSE)
-
-      if (is.na(proj4string(obj))) {
-
-        proj4string(obj) <- CRS("+proj=longlat +datum=NAD83 +no_defs")
-
-      }
-
-    } else if (class == "sf") {
-
-      obj <- st_read(dsn = tmp, layer = shape,
-                     quiet = TRUE, stringsAsFactors = FALSE)
-
-      if (is.na(st_crs(obj)$proj4string)) {
-
-        st_crs(obj) <- "+proj=longlat +datum=NAD83 +no_defs"
-
-      }
+      st_crs(obj) <- "+proj=longlat +datum=NAD83 +no_defs"
 
     }
 
@@ -261,16 +236,17 @@ load_tiger <- function(url,
     obj$STATEFP <- obj$ST
   }
 
-  return(obj)
-
+  if (class == "sp") {
+    warning(stringr::str_wrap("Spatial* (sp) classes are no longer formally supported in tigris as of version 2.0. We strongly recommend updating your workflow to use sf objects (the default in tigris) instead.", 50), call. = FALSE)
+    return(sf::as_Spatial(obj))
+  } else {
+    return(obj)
+  }
 }
 
 #' Easily merge a data frame to a spatial data frame
 #'
-#' The pages of StackOverflow are littered with questions about how to merge a regular data frame to a
-#' spatial data frame in R.  The \code{merge} function from the sp package operates under a strict set of
-#' assumptions, which if violated will break your data.  This function wraps a couple StackOverflow answers
-#' I've seen that work in a friendlier syntax.
+#' This function should be considered deprecated.  Please update your workflow to use sf objects and dplyr's \code{*_join()} family of functions instead.
 #'
 #' @param spatial_data A spatial data frame to which you want to merge data.
 #' @param data_frame A regular data frame that you want to merge to your spatial data.
@@ -278,7 +254,7 @@ load_tiger <- function(url,
 #' @param by_df The column name you'll use for the merge from your regular data frame.
 #' @param by (optional) If a named argument is supplied to the by parameter, geo_join will assume that the join columns in the spatial data and data frame share the same name.
 #' @param how The type of join you'd like to perform.  The default, 'left', keeps all rows in the spatial data frame, and returns NA for unmatched rows.  The alternative, 'inner', retains only those rows in the spatial data frame that match rows from the target data frame.
-#' @return a \code{SpatialXxxDataFrame} object
+#' @return a joined spatial/data frame object
 #' @export
 #' @examples \dontrun{
 #'
@@ -503,20 +479,13 @@ list_counties <- function(state) {
 #' @return one combined Spatial object
 #' @export
 #' @examples \dontrun{
-#' library(sp)
-#' library(rgeos)
-#' library(maptools)
-#' library(maps)
 #' library(tigris)
 #'
 #' me_ctys <- list_counties("me")
 #' aw <- lapply(me_ctys$county_code[1:3], function(x) {
 #'   area_water("Maine", x)
-#' })
-#' tmp <- rbind_tigris(aw)
-#' tmp_simp <- gSimplify(tmp, tol=1/200, topologyPreserve=TRUE)
-#' tmp_simp <- SpatialPolygonsDataFrame(tmp_simp, tmp@@data)
-#' plot(tmp_simp)
+#' }) %>%
+#'   rbind_tigris()
 #' }
 
 rbind_tigris <- function(...) {
@@ -567,34 +536,7 @@ rbind_tigris <- function(...) {
                          "SpatialPixelsDataFrame", "SpatialPointsDataFrame",
                          "SpatialPolygonsDataFrame")) {
 
-    if (length(obj_classes) == 1 &
-        !any(sapply(obj_attrs, is.null)) &
-        length(obj_attrs_u)==1) {
-
-      el_nams <- names(elements)
-
-      if (is.null(el_nams)) {
-        el_nams <- rep(NA, length(elements))
-      }
-
-      el_nams <- ifelse(el_nams == "", NA, el_nams)
-
-      el_nams <- sapply(el_nams, function(x) {
-        ifelse(is.na(x), gsub("-", "", UUIDgenerate(), fixed=TRUE), x)
-      })
-
-      tmp <- lapply(1:(length(elements)), function(i) {
-        elem <- elements[[i]]
-        spChFIDs(elem, sprintf("%s%s", el_nams[i], rownames(elem@data)))
-      })
-
-      tmp <- Reduce(spRbind, tmp)
-      attr(tmp, "tigris") <- obj_attrs_u
-      return(tmp)
-
-    } else {
-      stop("Objects must all be Spatial*DataFrame objects and all the same type of tigris object.", call.=FALSE)
-    }
+    stop("Spatial* classes are no longer supported in tigris as of version 2.0. You will need to install an earlier version of tigris with `remotes::install_version()`.")
 
   } else if ("sf" %in% obj_classes) {
 
@@ -736,7 +678,8 @@ erase_water <- function(input_sf,
     suppressMessages(tigris::area_water(
       state = stringr::str_sub(cty, 1, 2),
       county = stringr::str_sub(cty, 3, 5),
-      progress_bar = FALSE
+      progress_bar = FALSE,
+      year = year
     ))
   }) %>%
     dplyr::bind_rows() %>%
@@ -761,15 +704,16 @@ erase_water <- function(input_sf,
 #' `@inheritSection load_tiger_doc_template Additional Arguments`
 #'
 #' @param ... arguments to be passed to internal function `load_tiger`, which is not exported. See Additional Arguments.
-#' @param year the data year; defaults to 2020
+#' @param year the data year; defaults to 2021
 #'
 #' @section Additional Arguments:
 #' Additional arguments that can be passed in `...` are:
-#'  * `class` Desired class of return object: `"sf"` (the default) or `"sp"`.
+#'  * `class` Desired class of return object: `"sf"` (the default) or `"sp"`.  sp classes should be considered deprecated as of tigris version 2.0, but legacy support is still available.
 #'  * `progress_bar` If set to `FALSE`, do not display download progress bar (helpful for R Markdown documents). Defaults to `TRUE`.
 #'  * `keep_zipped_shapefile` If set to `TRUE`, do not delete zipped shapefile (stored in temporary directory or `TIGRIS_CACHE_DIR`
 #'     depending on the configuration of global option `"tigris_use_cache"`). Defaults to `FALSE`.
 #'  * `refresh` Whether to re-download cached shapefiles (`TRUE` or `FALSE`) . The default is either `FALSE` or the value of global
 #'     option `"tigris_refresh"` if it is set. Specifying this argument will override the behavior set in `"tigris_refresh"` global option.
+#'  * `filter_by` Geometry used to filter the output returned by the function.  Can be an sf object, an object of class `bbox`, or a length-4 vector of format `c(xmin, ymin, xmax, ymax)` that can be converted to a bbox. Geometries that intersect the input to `filter_by` will be returned.
 #' @name load_tiger_doc_template
 NULL
